// -*- c++ -*-

#ifndef DEVICEVIEW_H
#define DEVICEVIEW_H

#include <qwidget.h>
#include <parted/parted.h>

class QCheckBox;
class QIconView;
class QLabel;

class DiskView;

/**
 * Provides a view of a disk. This widget displays information about the disk itself and
 * the partitions it contains, it also provides access to the actions a user can perform.
 *
 * @author Richard Moore, rich@kde.org
 * @version $Id: deviceview.h,v 1.1 2002/03/08 00:49:32 rich Exp $
 */
class DeviceView : public QWidget
{
  Q_OBJECT

public:
  DeviceView( QWidget *parent=0, const char *name=0 );
  ~DeviceView();

public slots:
  void setDevice( PedDevice *device );
  void setPartition( PedPartition *part );

signals:
  void setTitle( const QString &title, const QString &subTitle );

protected:
  void resizeEvent( QResizeEvent *e );
  void updateFlag( QCheckBox *check, PedPartition *part, PedPartitionFlag flag );

private:
  DiskView *disk;

  QCheckBox *bootablePart;
  QCheckBox *rootPart;
  QCheckBox *swapPart;
  QCheckBox *hiddenPart;
  QCheckBox *raidPart;
  QCheckBox *lvmPart;
  QCheckBox *lbaPart;

  QLabel *cmdLabel;
  QIconView *cmds;
};

#endif // DEVICEVIEW_H
