// -*- c++ -*-

#ifndef DISKVIEW_H
#define DISKVIEW_H

#include <qlistview.h>
#include <parted/parted.h>

/**
 * An item that represents a partition in a DiskView.
 */
class DiskViewItem : public QListViewItem
{
  friend class DiskView;

public:
  DiskViewItem( QListView *parent, const QString &diskName, const QString &fstype,
		const QString &sizeStr, const QString &startStr, const QString &endStr );
  DiskViewItem( QListViewItem *parent, const QString &diskName, const QString &fstype,
		const QString &sizeStr, const QString &startStr, const QString &endStr );

  ~DiskViewItem() {}

private:
  PedPartition *part;
};

/**
 * A widget that displays a list of all partitions on a disk.
 *
 * @author Richard Moore, rich@kde.org
 * @version $Id: diskview.h,v 1.1 2002/03/08 00:49:32 rich Exp $
 */
class DiskView : public QListView
{
  Q_OBJECT

public:
  DiskView( QWidget *parent=0, const char *name=0 );
  ~DiskView();

  void setDisk( PedDisk *disk );
  void addPartition( PedDisk *disk, PedPartition *part );
  void addLogicalPartition( QListViewItem *parent, PedDisk *disk, PedPartition *part );

signals:
  void partitionSelected( PedPartition * );

protected slots:
  void selectionChanged( QListViewItem *i );
};

#endif // DISKVIEW_H
